==> spip_2.1.13-1.debian.tar.gz: debian/mutualisation/mutualisation_tailles.js <==
// Ces fonction ont pour but de lancer en ajax les calculs de tailles de rpertoires et sous rpertoire
// pour l'ensemble des sites mutualiss.
// Si c'est rpertoire sont trop gros, il arrive qu'on atteigne le temps limite d'execution d'une requete php
// Pour viter cela, il est mis en place un systme qui relance l'opration en descendant d'un cran dans l'arborescence

nb_demandes = new Array();

// Lance la recherche de taille sur le rpertoire rep de tous les sites du tableau tableau_sites
// @author      Yffic
// @param       string   rep    rpertoire a dimensionner (typiquement local, IMG ou cache)

function rechercher_tailles(rep) {
	var id ;
	$("#"+rep+"calculer").attr('disabled', 'disabled');
	//tableau_sites = new Array();
	//tableau_sites.push(["../../sites/www.domaine.ltd"]); // Pour tester sur un seul site
	$.each(tableau_sites,function(num_site,site){
		// Cas particulier du dossier cache
		if(rep=="cache") cible="tmp/cache" ;
		else cible=rep ;
		// Recherche des sous-rpertoires
		$.get("../mutualisation/inc/dirliste.php",{
			dir: site+"/"+cible
		},function(liste){
			id="#"+rep+(num_site+1) ;
			gerer_liste(liste,site,cible,500,id);
		});
	});
}

// Rcupre la liste des sous-rpertoires de cible
// @author      Yffic
// @param       string   liste        chaine de la forme XXX##rep1##rep2...
//										        o XXX vaut -1 si erreur et sinon le poids des fichiers du rpertoire (hors sous-rpertoires) en Mo
//										        o rep1, rep2,... le nom des sous-rpertoires
//              string   site         site en cours de traitement
//              string   cible        sous rpertoire du site
//              string   taille_max   taille_max au dessus de laquelle l'exploration doit descendre d'un niveau
//              string   ident        ident du td  renseigner

function gerer_liste(liste,site,cible,taille_max,ident){
	//$("#trace").append("liste: "+liste+" cible: "+cible+" ident: "+ident+"<br />") ;
	if(liste==-1) {
		$(ident).removeClass("loading").append("<em><small><span class=\"erreur\">Erreur&nbsp;!"+site+"/"+cible+"</span></small></em>");
	} else {
		var tableau_file = liste.split("##");
		// On rcupre le contenu courant du ident et on y ajoute la taille des fichiers de la cible
		if($(ident).text()=="") contenu=0;
		else contenu=parseFloat($(ident).text());
		somme = contenu + parseFloat(tableau_file[0]) ;
		$(ident).empty().append(somme.toFixed(2)) ;
		// On supprime le premier lment, Il ne reste donc plus que les sous-rpertoires
		tableau_file.shift() ;
		nb_demandes[ident] = 0;
		// Si aucun sous-rpertoire, on efface la roue loading
		if(tableau_file.length == 0) $(ident).removeClass("loading") ;
		// Pour chaque sous-epertoire, on va demander sa taille
		$.each(tableau_file,function(k,file){
			$(ident).addClass("loading")
			nb_demandes[ident] ++ ;
			$.get("../mutualisation/inc/dirsize.php",{
				dir: site+"/"+cible+"/"+file,
				taille_max: taille_max
			},function(taille){gerer_taille(taille,site,cible,taille_max,ident);});
		});
	}
}

// Rcupre la taille d'un des sous-rpertoires de cible
// @author      Yffic
// @param       string   taille       chaine de la forme XXX##erreur
//										        o XXX vaut -1 si erreur, -2 si taille max atteinte et sinon la taille du rpertoire en Mo
//										        o erreur explicite le type d'arreur
//              string   site         site en cours de traitement
//              string   cible        sous rpertoire du site
//              string   taille_max   taille_max au dessus de laquelle l'exploration doit descendre d'un niveau
//              string   ident        ident du td  renseigner

function gerer_taille(taille,site,cible,taille_max,ident){
	//$("#trace").append("taille: "+taille+" cible: "+cible+" ident: "+ident+"<br />") ;
	nb_demandes[ident] -- ;
	var retour = taille.split("##");
	// Erreur si -1 ou vide (peut arriver si on atteint le temps max d'execution php
	if((retour[0]==-1) || (taille=="")) {
		$(ident).removeClass("loading").append("<em><small><span class=\"erreur\">Erreur&nbsp;! "+retour[1]+"</span></small></em>");
	} else if(retour[0]==-2) {
		// On a atteint la limite, on va relancer l'opration en descendant d'un niveau
		// mais en mettant une taille max a 0 (soit pas de limite)
		site=(retour[1])+"..";
		cible="";
		$.get("../mutualisation/inc/dirliste.php",{
			dir: site+"/"+cible
		},function(liste){gerer_liste(liste,site,cible,0,ident);});
	} else {
		// On ajoute le rsultat au contenu du champs
		somme = parseFloat($(ident).text()) + parseFloat(retour[0]) ;
		$(ident).empty().append(somme.toFixed(2));
		// Si c'est la dernire demande qui revient, on supprime la roue loading
		if(nb_demandes[ident] == 0) $(ident).removeClass("loading") ;
	}
}

==> spip_2.1.24-1.debian.tar.gz: debian/mutualisation/mutualisation_tailles.js <==
// Ces fonction ont pour but de lancer en ajax les calculs de tailles de rpertoires et sous rpertoire
// pour l'ensemble des sites mutualiss.
// Si c'est rpertoire sont trop gros, il arrive qu'on atteigne le temps limite d'execution d'une requete php
// Pour viter cela, il est mis en place un systme qui relance l'opration en descendant d'un cran dans l'arborescence

nb_demandes = new Array();

// Lance la recherche de taille sur le rpertoire rep de tous les sites du tableau tableau_sites
// @author      Yffic
// @param       string   rep    rpertoire a dimensionner (typiquement local, IMG ou cache)

function rechercher_tailles(rep) {
	var id ;
	$("#"+rep+"calculer").attr('disabled', 'disabled');
	//tableau_sites = new Array();
	//tableau_sites.push(["../../sites/www.domaine.ltd"]); // Pour tester sur un seul site
	$.each(tableau_sites,function(num_site,site){
		// Cas particulier du dossier cache
		if(rep=="cache") cible="tmp/cache" ;
		else cible=rep ;
		// Recherche des sous-rpertoires
		$.get("../mutualisation/inc/dirliste.php",{
			dir: site+"/"+cible
		},function(liste){
			id="#"+rep+(num_site+1) ;
			gerer_liste(liste,site,cible,500,id);
		});
	});
}

// Rcupre la liste des sous-rpertoires de cible
// @author      Yffic
// @param       string   liste        chaine de la forme XXX##rep1##rep2...
//										        o XXX vaut -1 si erreur et sinon le poids des fichiers du rpertoire (hors sous-rpertoires) en Mo
//										        o rep1, rep2,... le nom des sous-rpertoires
//              string   site         site en cours de traitement
//              string   cible        sous rpertoire du site
//              string   taille_max   taille_max au dessus de laquelle l'exploration doit descendre d'un niveau
//              string   ident        ident du td  renseigner

function gerer_liste(liste,site,cible,taille_max,ident){
	//$("#trace").append("liste: "+liste+" cible: "+cible+" ident: "+ident+"<br />") ;
	if(liste==-1) {
		$(ident).removeClass("loading").append("<em><small><span class=\"erreur\">Erreur&nbsp;!"+site+"/"+cible+"</span></small></em>");
	} else {
		var tableau_file = liste.split("##");
		// On rcupre le contenu courant du ident et on y ajoute la taille des fichiers de la cible
		if($(ident).text()=="") contenu=0;
		else contenu=parseFloat($(ident).text());
		somme = contenu + parseFloat(tableau_file[0]) ;
		$(ident).empty().append(somme.toFixed(2)) ;
		// On supprime le premier lment, Il ne reste donc plus que les sous-rpertoires
		tableau_file.shift() ;
		nb_demandes[ident] = 0;
		// Si aucun sous-rpertoire, on efface la roue loading
		if(tableau_file.length == 0) $(ident).removeClass("loading") ;
		// Pour chaque sous-rpertoire, on va demander sa taille
		$.each(tableau_file,function(k,file){
			$(ident).addClass("loading")
			nb_demandes[ident] ++ ;
			$.get("../mutualisation/inc/dirsize.php",{
				dir: site+"/"+cible+"/"+file,
				taille_max: taille_max
			},function(taille){gerer_taille(taille,site,cible,taille_max,ident);});
		});
	}
}

// Rcupre la taille d'un des sous-rpertoires de cible
// @author      Yffic
// @param       string   taille       chaine de la forme XXX##erreur
//										        o XXX vaut -1 si erreur, -2 si taille max atteinte et sinon la taille du rpertoire en Mo
//										        o erreur explicite le type d'arreur
//              string   site         site en cours de traitement
//              string   cible        sous rpertoire du site
//              string   taille_max   taille_max au dessus de laquelle l'exploration doit descendre d'un niveau
//              string   ident        ident du td  renseigner

function gerer_taille(taille,site,cible,taille_max,ident){
	//$("#trace").append("taille: "+taille+" cible: "+cible+" ident: "+ident+"<br />") ;
	nb_demandes[ident] -- ;
	var retour = taille.split("##");
	// Erreur si -1 ou vide (peut arriver si on atteint le temps max d'execution php
	if((retour[0]==-1) || (taille=="")) {
		$(ident).removeClass("loading").append("<em><small><span class=\"erreur\">Erreur&nbsp;! "+retour[1]+"</span></small></em>");
	} else if(retour[0]==-2) {
		// On a atteint la limite, on va relancer l'opration en descendant d'un niveau
		// mais en mettant une taille max a 0 (soit pas de limite)
		site=(retour[1])+"..";
		cible="";
		$.get("../mutualisation/inc/dirliste.php",{
			dir: site+"/"+cible
		},function(liste){gerer_liste(liste,site,cible,0,ident);});
	} else {
		// On ajoute le rsultat au contenu du champs
		somme = parseFloat($(ident).text()) + parseFloat(retour[0]) ;
		$(ident).empty().append(somme.toFixed(2));
		// Si c'est la dernire demande qui revient, on supprime la roue loading
		if(nb_demandes[ident] == 0) $(ident).removeClass("loading") ;
	}
}
